@@ -137,7 +137,7 @@ class Checker:
         for thread in self.threads:
             thread.start()
 
-    def worker(self, check, q, proxy):
+    def worker(self, check, q):
         while True:
             try:
                 combo = q.get()
@@ -149,7 +149,12 @@ class Checker:
                     password = combo.split(";")[1]
             except queue.Empty:
                 return
+
             while True:
+                if self.proxy:
+                    proxy = self.get_proxy()
+                else:
+                    proxy = None
                 result = check(email, password, proxy)
                 match result[0]:
                     case "good":
@@ -218,11 +223,7 @@ class Checker:
             q.put_nowait(line)
 
         for _ in range(thread_count):
-            if self.proxy:
-                proxy = self.get_proxy()
-            else:
-                proxy = None
-            threading.Thread(target=self.worker, args=(check, q, proxy)).start()
+            threading.Thread(target=self.worker, args=(check, q)).start()
 
         '''
         Your check function must have 3 parameters: email, password and proxy.
